QualarooFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • QualarooFlutterPlatform
Implementers

Constructors

QualarooFlutterPlatform()
Constructs a QualarooFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initializeQualarooSdk(dynamic apiKey) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeUserProperty(dynamic key) → Future<void>
setPreferredLanguage(dynamic language) → Future<void>
setUserId(dynamic userId) → Future<void>
setUserProperty(dynamic key, dynamic value) → Future<void>
showSurvey(dynamic aliasName) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ QualarooFlutterPlatform
The default instance of QualarooFlutterPlatform to use.
getter/setter pair